@import url(http://fonts.googleapis.com/css?family=Montserrat:400,700);
@import url(http://fonts.googleapis.com/css?family=Source+Code+Pro:300,400,500);

body {
    font: 400 13px/26px "Open Sans",sans-serif;
    color: #687E95;
    text-rendering: optimizelegibility;
    background-color: #FFFFFF;
}

.wy-body-for-nav {
    background: #FFFFFF;
}

.wy-nav-content {
    background: #FFFFFF;
}

.wy-nav-content-wrap {
    background: #FFFFFF;
    margin-left: 300px;
    padding-left: 70px;
    padding-right: 70px;
    /*box-shadow: 0 0 1px rgba(0, 0, 0, 0.1);*/
    max-width: 940px;
}

@media only screen and (max-width: 768px) {
    .wy-nav-content-wrap {
        margin-left: 0;
        padding-left: 0;
        padding-right: 0;
    }
}

.wy-nav-top {
    background: #1A1A1A;
}

.wy-plain-list-disc li,
.rst-content .section ul li,
.rst-content .toctree-wrapper ul li,
article ul li {
    font: 400 13px/26px "Open Sans",sans-serif;
    color: #687E95;
}

.wy-nav-side {
    position: fixed;
    background: #1A1A1A;
    /*box-shadow: 0px 0 1px rgba(0, 0, 0, 0.1) inset;
    overflow: scroll;
    bottom: inherit;*/
}

.wy-side-nav-search {
    font-family: "Open Sans", "Roboto", sans-serif;
    font-size: 15px;
    background-color: transparent;
    color: #7A7A7A;
}

.wy-menu-vertical ul {
    font-family: "Open Sans", "Roboto", sans-serif;
    margin-right: 1em;
}

.wy-menu-vertical > ul {
    padding-left: 20px;
}

.wy-menu-vertical li.current {
    background: transparent;
}

.wy-menu-vertical > ul > li {
    margin-bottom: 30px;
}

.wy-menu-vertical > ul > li > ul {
    display: block;
}

.wy-menu-vertical li.current > ul {
    background: transparent;
    padding: 0;
}

.wy-menu-vertical li.on a, .wy-menu-vertical li.current > a {
    background: transparent;
    border: 0;
    font-weight: 400;
}

.wy-menu-vertical li a {
    opacity: 1;
}

.wy-menu-vertical > ul > li > a,
.wy-menu-vertical > ul > li > a:visited
{
    color: #9A9A9A;
    opacity: 1;
    -webkit-transition: all 0.3s;
    -moz-transition: all 0.3s;
    -ms-transition: all 0.3s;
    -o-transition: all 0.3s;
    transition: all 0.3s;
}

.wy-menu-vertical > ul > li > a:hover
{
    color: #FAC322;
    opacity: 1;
}

.wy-menu-vertical li a:hover {
    background: transparent;
}

.wy-menu-vertical li a, .wy-menu-vertical li.current > a {
    border-radius: 0 5px 5px 0;
}

.wy-menu-vertical li.current > ul > li > a {
    font-size: 13px;
    border-right: 0;
    opacity: 1;
    padding: 0.4045em 20px;
}

.wy-menu-vertical li.current > a {
    font-size: 13px;
    border-right: 0;
}

.wy-menu-vertical li.toctree-l2.current > a {
    background: none;
    font-size: 13px;
    color: #EF6155 !important;
    padding-left: 3.027em;
}

.wy-menu-vertical li.toctree-l1.current > ul > li > a::before {
    font-family: "FontAwesome";
    content: "";
    color: #EC7600;
    font-size: 8px;
    position: absolute;
    top: 4px;
    left: 3em;
    opacity: 0.3;
    display: none;
}

.wy-menu-vertical li.toctree-l1.current > ul > li.toctree-l2.current > a::before {
    content: "##";
    color: #EF6155;
    font-size: 13px;
    position: absolute;
    top: 6px;
    left: 20px;
    opacity: 1;
    display: block;
}

.wy-menu-vertical li.toctree-l2.current ul {
    display: none !important;
}

.wy-menu-vertical li.toctree-l2.current li.toctree-l3 > a  {
    background: none;
    padding: 0 4em;
    font-size: 12px;
}

.wy-menu-vertical li.toctree-l2.current li.toctree-l3.current ul {
    display: None;
}

.wy-menu-vertical a,
.wy-menu-vertical a:visited {
    color: #7A7A7A;
    line-height: 20px;
    font-size: 13px;
}

.wy-menu-vertical a:hover {
    color: #5A5A5A;
}

.wy-menu-vertical > ul > li > ul > li > a,
.wy-menu-vertical > ul > li > ul > li > a:visited,
.wy-menu-vertical li.current a,
.wy-menu-vertical li.current a:visited {
    color: #7A7A7A;
    background: transparent;
    -webkit-transition: all 0.3s;
    -moz-transition: all 0.3s;
    -ms-transition: all 0.3s;
    -o-transition: all 0.3s;
    transition: all 0.3s;
}

.wy-menu-vertical > ul > li > ul > li > a:hover,
.wy-menu-vertical li.current a:hover {
    color: #EF6155;
    background: transparent;
}

.wy-menu-vertical li.current > a {
    color: #579ED1 !important;
    padding-left: 2.427em;
}

.wy-menu-vertical li.current > a:hover {
}

.wy-side-nav-search input[type="text"] {
    font-family: "Open Sans", "Roboto", sans-serif;
    border: 0;
    background: none;
    box-shadow: none;
    color: #7A7A7A;
    font-size: 13px;
    width: 90%;
    border-radius: 0;
    border-bottom: 1px solid rgba(129, 150, 154, 0.7);
    opacity: 1;
    padding: 6px 0;
}

.wy-side-nav-search > a,
.wy-side-nav-search > a:visited {
    color: #9A9A9A;
}

.wy-side-nav-search > a:hover {
    background: none;
}

.wy-menu-vertical li {
    position: relative;
}

.wy-menu-vertical li span.toctree-expand::before,
.wy-menu-vertical li.on a span.toctree-expand::before,
.wy-menu-vertical li.current > a span.toctree-expand::before,
.wy-menu-vertical li a span.toctree-expand,
.wy-menu-vertical li a span.toctree-expand:before {
    display: none;
}

.wy-menu-vertical li.current ul li a span.toctree-expand,
.wy-menu-vertical li.on a:hover span.toctree-expand,
.wy-menu-vertical li.current a:hover span.toctree-expand{
    display: none;
}

.wy-menu-vertical li.toctree-l1.current:before {
    content: "#";
    color: #579ED1;
    font-size: 13px;
    position: absolute;
    top: 3px;
    left: 20px;
    z-index: 2;
    display: block;
}

.wy-menu-vertical li.toctree-l1:before {
    font-family: FontAwesome;
    content: "";
    opacity: 1;
    color: #1999B3;
    font-size: 10px;
    top: 2px;
    position: absolute;
    left: 12px;
    z-index: 2;
    display: none;
}

.rst-content table.docutils,
.rst-content table.field-list {
    border: medium none;
    width: 100%;
}

.rst-content table.docutils thead th,
.rst-content table.field-list thead th
{
    font-family: "Montserrat", serif;
    text-transform: uppercase;
    color: #7A7A7A;
    font-weight: 500;
}

.rst-content table.docutils thead th,
.rst-content table.field-list thead th,
.rst-content table.docutils tbody td,
.rst-content table.field-list tbody td
{
    border-top: 0;
    border-bottom: 1px solid rgba(230, 230, 230, 0.7);
    border-left: 0;
    border-right: 0;
    padding: 20px;
    white-space: pre-wrap;
}

.wy-table-odd td,
.wy-table-striped tr:nth-child(2n-1) td,
.rst-content table.docutils:not(.field-list) tr:nth-child(2n-1) td {
    background: none;
}

.wy-table td, .rst-content table.docutils td {
    font-size: 100% !important;
}

.rst-content table.docutils tbody td tt.code,
.rst-content table.field-list tbody td tt.code,
.rst-content table.docutils tbody td code.code,
.rst-content table.field-list tbody td code.code
{
    border: 0;
    background: none;
    padding: 0.3em 0;
    color: #26A6A6;
}

.rst-content .highlighted {
    border: 1px solid rgb(250, 195, 34);
    padding: 0 4px;
    border-radius: 3px;
    color: #BA8300;
    display: inline;
    font-weight: inherit;
    background: rgba(250, 195, 34, 0.6) none repeat scroll 0% 0%;
}

h1, h2, h3, h4, h5, h6 {
    color: #384E65;
    padding: 10px 0;
    font-family: "Open Sans", "Montserrat", serif;
    line-height: 1;
    margin: 40px 0 30px 0;
    font-weight: 300;
    position: relative;
    -moz-osx-font-smoothing: grayscale;
    -webkit-font-smoothing: antialiased;
}

.rst-content h1 .headerlink,
.rst-content h2 .headerlink,
.rst-content h3 .headerlink,
.rst-content h4 .headerlink,
.rst-content h5 .headerlink,
.rst-content h6 .headerlink {
    visibility: hidden;
    color: inherit;
    font-size: inherit;
    margin: 0;
}

.rst-content h1 .headerlink:before,
.rst-content h2 .headerlink:before,
.rst-content h3 .headerlink:before,
.rst-content h4 .headerlink:before,
.rst-content h5 .headerlink:before,
.rst-content h6 .headerlink:before {
    font-family: inherit;
    visibility: visible;
    position: absolute;
    left: -40px;
    width: 100%;
    content: "#";
    opacity: 0;
    font-weight: inherit;
    -webkit-transition: all 0.3s;
    -moz-transition: all 0.3s;
    -ms-transition: all 0.3s;
    -o-transition: all 0.3s;
    transition: all 0.3s;
}

.rst-content h1 .headerlink:before {
    top: 20px;
}

.rst-content h1:hover .headerlink,
.rst-content h2:hover .headerlink,
.rst-content h3:hover .headerlink,
.rst-content h4:hover .headerlink,
.rst-content h5:hover .headerlink,
.rst-content h6:hover .headerlink {
    display: inline;
    color: inherit;
}

.rst-content h1:hover .headerlink:before,
.rst-content h2:hover .headerlink:before,
.rst-content h3:hover .headerlink:before,
.rst-content h4:hover .headerlink:before,
.rst-content h5:hover .headerlink:before,
.rst-content h6:hover .headerlink:before {
    opacity: 1;
}

.rst-content h1 .headerlink:after,
.rst-content h2 .headerlink:after,
.rst-content h3 .headerlink:after,
.rst-content h4 .headerlink:after,
.rst-content h5 .headerlink:after,
.rst-content h6 .headerlink:after {
    visibility: hidden;
    content: "";
}

h1 {
    font-size: 44px;
}

h2 {
    font-size: 38px;
    color: #579ED1;
    position: relative;
}

h2:before {
    display: none;
    font-family: "FontAwesome";
    content: "#";
    margin-left: -30px;
    font-size: 38px;
    top: 11px;
    color: #579ED1 !important;
    opacity: 0.6;
    position: absolute;
}

h3 {
    font-size: 24px;
}

h4 {
    font-size: 20px;
}


h1,
h1 a,
.header h1,
.header h1 a {
    font: 300 44px/66px "Open Sans", "Roboto","Montserrat",sans-serif;
    margin-bottom: 30px;
    color: #485E75;
}

a, a:visited {
    color: #009CD4;
}

a:hover {
    color: #48B0F7;
}

a > em {
    font-style: normal;
}

p {
    font: 400 13px/26px "Open Sans",sans-serif;
    color: #687E95;
}

b, strong {
   font-weight: 600;
}

pre, pre code, .rst-content tt, code.docutils, .rst-content dl:not(.docutils) code {
    font-family: "Source Code Pro", "Consolas", "Menlo", "Monaco", "Courier New", Courier, monospace;
    color: #26A6A6;
    background-color: transparent;
    font-size: 13px;
    font-weight: 400;
    border: 0;
    padding: 0;
}

pre, code, .rst-content ttc {
	font-family: "Source Code Pro", "Consolas", "Menlo", "Monaco", "Courier New", Courier, monospace;
	font-weight: 400;
    border-radius: 3px;
    font-size: 13px;
    margin: 0px 2px;
}

div[class^="highlight"] {
    border: 0;
    background: transparent;
}

.higlight {
    background: transparent;
}

.highlight > pre, div[class^="highlight"] pre {
    font-family: "Source Code Pro", "Consolas", "Menlo", "Monaco", "Courier New", Courier, monospace;
	border-left: 1px solid #F2F2F2;
    font-size: 13px;
    padding: 2% 4%;
    margin-left: 1%;
    color: #788EA5;
    /*background-color: #FAFAFA;*/
}

code, .rst-content tt, .rst-content code {
    font-family: "Source Code Pro", "Consolas", "Menlo", "Monaco", "Courier New", Courier, monospace;
}

code {
    color: #CB6077;
    background-color: transparent;
    font-size: 13px;
    font-weight: 500;
}

p > code,
.rst-content tt,
p > code.docutils {
    color: #26A6A6;
    padding: 0;
    display: inline;
    font-weight: 400;
    border: 0;
    background-color: transparent;
}

.rst-content tt.literal, .rst-content tt.literal, .rst-content code.literal, .rst-content dl:not(.docutils) code {
    color: #1976BF;
}

.rst-content .admonition-title {
    display: none;
}

.rst-content .note,
.rst-content .warning,
.rst-content .tip,
.rst-content .caution,
.rst-content .versionchanged,
.rst-content .versionadded
{
    padding: 4% 4%;
    margin: 30px 0;
    background: transparent;
}

.rst-content .note .highlight > pre,
.rst-content .note div[class^="highlight"] pre,
.rst-content .warning .highlight > pre,
.rst-content .warning div[class^="highlight"] pre,
.rst-content .versionadded .highlight > pre,
.rst-content .versionadded div[class^="highlight"] pre,
.rst-content .tip .highlight > pre,
.rst-content .tip div[class^="highlight"] pre,
.rst-content .caution .highlight > pre,
.rst-content .caution div[class^="highlight"] pre {
    margin-left: 0;
    border-left: 0;
}

.rst-content .note {
    border-left: 1px dotted rgba(50, 154, 188, 0.3);
    border-right: 1px dotted rgba(50, 154, 188, 0.3);
    background: rgba(50, 154, 188, 0.02);
    color: #3399BB !important;
    box-shadow: 0 0 2px rgba(50, 154, 188, 0.1);
}

.rst-content .tip {
    border-left: 1px dotted rgba(73,182,127, 0.3);
    border-right: 1px dotted rgba(73,182,127, 0.3);
    background: rgba(73,182,127, 0.02);
    color: #49B67F !important;
    box-shadow: 0 0 2px rgba(73,182,127, 0.1);
}

.rst-content .tip > p {
    color: #49B67F !important;
}

.rst-content .tip > p code {
    color: #19864F !important;
}

.rst-content .warning,
.rst-content .caution {
    border-left: 1px dotted rgba(249, 145, 87, 0.3);
    border-right: 1px dotted rgba(249, 145, 87, 0.3);
    background: rgba(249, 145, 87, 0.02);
    color: #F99157 !important;
    box-shadow: 0 0 2px rgba(249, 145, 87, 0.1);
}

.rst-content .note > p {
    color: #39B !important;
}

.rst-content .warning > p,
.rst-content .caution > p
{
    color: #F99157 !important;
}

.rst-content .versionadded,
.rst-content .versionchanged
{
    border-left: 1px dotted rgba(102, 119, 187, 0.3);
    border-right: 1px dotted rgba(102, 119, 187, 0.3);
    background: rgba(102, 119, 187, 0.02);
    color: #6677BB !important;
    margin-bottom: 20px;
    position: relative;
    box-shadow: 0 0 2px rgba(102, 119, 187, 0.1);
}

.rst-content .versionadded > p > span,
.rst-content .versionchanged > p > span
{
    font-family: "Montserrat", serif;
    display: block;
    font-size: 12px;
    margin-bottom: 20px;
    text-transform: uppercase;
    color: #36479B !important;
}

.rst-content .versionadded > p,
.rst-content .versionchanged > p
{
    color: #6677BB !important;
}

.rst-content .versionadded > p code,
.rst-content .versionchanged > p code
{
    color: #36479B !important;
}

.rst-content .versionadded > p,
.rst-content .versionchanged > p {
    margin-bottom: 0;
}

.rst-content .note .versionchanged
{
    padding-left: 4%;
}

.note code {
    border: 0;
    padding: 0;
    display: inline;
}

.note ul li,
.warning ul li {
    color: inherit !important;
}

.warning code,
.warning tt {
    border: 0;
    padding: 0;
    display: inline;
    color: #D9664F !important;
}

.btn-neutral,
.btn-neutral:visited {
    color: #808080 !important;
    font: 400 12px/20px Montserrat,Arial,sans-serif;
    text-transform: uppercase;
    padding: 6px 14px;
    border-radius: 4px;
    box-shadow: none;
    border: 0;
    transition: all 0.3s;
    background-color: transparent !important;
}

.btn-neutral:hover {
    background-color: transparent !important;
    color: rgba(25, 153, 179, 0.8) !important;
    /*color: rgba(0, 168, 192, 1) !important;*/
}

.btn-neutral:focus {
    background-color: transparent !important;
    color: rgba(25, 153, 179, 1) !important;
    box-shadow: none;
    padding: 6px 14px;
}

.btn-neutral span.fa {
    transition: all 0.3s;
}

.btn-neutral:hover span.fa-arrow-circle-left {
    padding-right: 5px;
}

.btn-neutral:hover span.fa-arrow-circle-right {
    padding-left: 5px;
}

.btn-neutral span.fa-arrow-circle-left:before {
    content: ''
}

.btn-neutral span.fa-arrow-circle-right:before {
    content: ''
}


/* Autodoc */
.rst-content table.field-list .field-name {
    text-align: left;
    white-space: nowrap;
    padding-right: 10px;
    width: 140px;
    font-weight: 600;
}

.rst-content table.field-list .field-body {
    padding: 8px 16px;
    text-align: left;
    vertical-align: top;
    border: 0;
}

.rst-content table.field-list .field-body ul {
    line-height: 0;
}

.rst-content table.field-list .field-body ul li {
    list-style: none;
    margin-left: 0;
    font-size: 100%;
}

.rst-content table.field-list td p {
    line-height: inherit;
}

.rst-content table.field-list .field-body strong {
    color: #F3888B;
    font-weight: 400;
    margin-top: 0;
}

.rst-content dl:not(.docutils).class > dt {
    border: 0;
    background: transparent;
    font-size: inherit;
    margin-bottom: 24px;
    color: #579ED1;
    font-weight: 600;
}

.rst-content dl:not(.docutils).class > dt > em,
.rst-content dl:not(.docutils).class > dt > em.property {
    font-weight: 400;
    font-style: normal;
}

.rst-content dl:not(.docutils).class > dt > code {
    color: #F9A167;
    font-weight: 400;
}

.rst-content dl:not(.docutils) dl.classmethod > dt,
.rst-content dl:not(.docutils) dl.method > dt {
    border-left: 1px solid #F2F2F2;
    background: transparent;
    font-size: inherit;
}

.rst-content dl:not(.docutils) dl.classmethod > dt > code,
.rst-content dl:not(.docutils) dl.method > dt > code {
    color: #D9664F;
    font-weight: 400;
}

.rst-content dl:not(.docutils) dl.classmethod > dt > em,
.rst-content dl:not(.docutils) dl.method > dt > em {
    font-weight: 400;
}

.rst-content dl:not(.docutils) dl.classmethod > dt > em.property,
.rst-content dl:not(.docutils) dl.method > dt > em.property {
    font-weight: 400;
    color: #7AC;
}


/* Solarized Light

For use with Jekyll and Pygments

http://ethanschoonover.com/solarized

SOLARIZED HEX      ROLE
--------- -------- ------------------------------------------
base01    #586e75  body text / default code / primary content
base1     #93a1a1  comments / secondary content
base3     #fdf6e3  background
orange    #cb4b16  constants
red       #dc322f  regex, special keywords
blue      #268bd2  reserved keywords
cyan      #2aa198  strings, numbers
green     #859900  operators, other keywords
*/

.highlight { background-color: #fdf6e3; color: #586e75 }
.highlight .c { color: #93a1a1 } /* Comment */
.highlight .err { color: #586e75 } /* Error */
.highlight .g { color: #586e75 } /* Generic */
.highlight .k { color: #859900 } /* Keyword */
.highlight .l { color: #586e75 } /* Literal */
.highlight .n { color: #586e75 } /* Name */
.highlight .o { color: #859900 } /* Operator */
.highlight .x { color: #cb4b16 } /* Other */
.highlight .p { color: #586e75 } /* Punctuation */
.highlight .cm { color: #93a1a1 } /* Comment.Multiline */
.highlight .cp { color: #859900 } /* Comment.Preproc */
.highlight .c1 { color: #93a1a1 } /* Comment.Single */
.highlight .cs { color: #859900 } /* Comment.Special */
.highlight .gd { color: #2aa198 } /* Generic.Deleted */
.highlight .ge { color: #586e75; font-style: italic } /* Generic.Emph */
.highlight .gr { color: #dc322f } /* Generic.Error */
.highlight .gh { color: #cb4b16 } /* Generic.Heading */
.highlight .gi { color: #859900 } /* Generic.Inserted */
.highlight .go { color: #586e75 } /* Generic.Output */
.highlight .gp { color: #586e75 } /* Generic.Prompt */
.highlight .gs { color: #586e75; font-weight: bold } /* Generic.Strong */
.highlight .gu { color: #cb4b16 } /* Generic.Subheading */
.highlight .gt { color: #586e75 } /* Generic.Traceback */
.highlight .kc { color: #cb4b16 } /* Keyword.Constant */
.highlight .kd { color: #268bd2 } /* Keyword.Declaration */
.highlight .kn { color: #859900 } /* Keyword.Namespace */
.highlight .kp { color: #859900 } /* Keyword.Pseudo */
.highlight .kr { color: #268bd2 } /* Keyword.Reserved */
.highlight .kt { color: #dc322f } /* Keyword.Type */
.highlight .ld { color: #586e75 } /* Literal.Date */
.highlight .m { color: #2aa198 } /* Literal.Number */
.highlight .s { color: #2aa198 } /* Literal.String */
.highlight .na { color: #586e75 } /* Name.Attribute */
.highlight .nb { color: #B58900 } /* Name.Builtin */
.highlight .nc { color: #268bd2 } /* Name.Class */
.highlight .no { color: #cb4b16 } /* Name.Constant */
/*.highlight .nd { color: #268bd2 }*/ /* Name.Decorator */
.highlight .nd { color: #cb4b16 }
.highlight .ni { color: #cb4b16 } /* Name.Entity */
.highlight .ne { color: #cb4b16 } /* Name.Exception */
.highlight .nf { color: #268bd2 } /* Name.Function */
.highlight .nl { color: #586e75 } /* Name.Label */
.highlight .nn { color: #586e75 } /* Name.Namespace */
.highlight .nx { color: #586e75 } /* Name.Other */
.highlight .py { color: #586e75 } /* Name.Property */
.highlight .nt { color: #268bd2 } /* Name.Tag */
.highlight .nv { color: #268bd2 } /* Name.Variable */
.highlight .ow { color: #859900 } /* Operator.Word */
.highlight .w { color: #586e75 } /* Text.Whitespace */
.highlight .mf { color: #ff9800 } /* Literal.Number.Float */
.highlight .mh { color: #ff9800 } /* Literal.Number.Hex */
.highlight .mi { color: #ff9800 } /* Literal.Number.Integer */
.highlight .mo { color: #ff9800 } /* Literal.Number.Oct */
.highlight .sb { color: #93a1a1 } /* Literal.String.Backtick */
.highlight .sc { color: #2aa198 } /* Literal.String.Char */
.highlight .sd { color: #586e75 } /* Literal.String.Doc */
.highlight .s2 { color: #2aa198 } /* Literal.String.Double */
.highlight .se { color: #cb4b16 } /* Literal.String.Escape */
.highlight .sh { color: #586e75 } /* Literal.String.Heredoc */
.highlight .si { color: #2aa198 } /* Literal.String.Interpol */
.highlight .sx { color: #2aa198 } /* Literal.String.Other */
.highlight .sr { color: #dc322f } /* Literal.String.Regex */
.highlight .s1 { color: #2aa198 } /* Literal.String.Single */
.highlight .ss { color: #2aa198 } /* Literal.String.Symbol */
.highlight .bp { color: #F2777A } /* Name.Builtin.Pseudo */
.highlight .vc { color: #F2777A } /* Name.Variable.Class */
.highlight .vg { color: #F2777A } /* Name.Variable.Global */
.highlight .vi { color: #F2777A } /* Name.Variable.Instance */
.highlight .il { color: #2aa198 } /* Literal.Number.Integer.Long */


/***** Mocha *****/
.highlight .s { color: #7BBDA4 } /* Literal.String */
.highlight .s1 { color: #7BBDA4 } /* Literal.String */
.highlight .si { color: #A89BB9 } /* Literal.String */
.highlight .m { color: #F4BC87 } /* Literal.Number */
.highlight .mf { color: #F4BC87 } /* Literal.Number */
.highlight .mh { color: #F4BC87 } /* Literal.Number */
.highlight .mi { color: #F4BC87 } /* Literal.Number */
.highlight .mo { color: #F4BC87 } /* Literal.Number */
.highlight .k { color: #BEB55B; font-weight: normal; } /* Keyword */
.highlight .kn { color: #BEB55B; font-weight: normal; } /* Keyword */
.highlight .ow { color: #BEB55B; font-weight: normal } /* Operator.Word */
.highlight .nc { color: #D28B71; font-weight: 500 } /* Name.Class */
.highlight .nf { color: #8AB3B5; font-weight: normal; } /* Name.Function */
.highlight .bp { color: #F3888B } /* Name.Builtin.Pseudo */
.highlight .vc { color: #F3888B } /* Name.Variable.Class */
.highlight .vg { color: #F3888B } /* Name.Variable.Global */
.highlight .vi { color: #F3888B } /* Name.Variable.Instance */
.highlight .nd { color: #BB9584 } /* Name.Decorator */
.highlight .ne { color: #CB6077; font-weight: 400 } /* Name.Exception */
.highlight .o { color: #8A8A8A } /* Operator */
.highlight .n { color: #8A8A8A }
.highlight .c { color: #B8AFAD; font-style: normal; }
.highlight .sd { color: #B8AFAD; font-style: normal; }
.highlight .nl { color: #A89BB9 } /* Name.Label */
.highlight .nn { color: #A89BB9 } /* Name.Namespace */
.highlight .nx { color: #A89BB9 } /* Name.Other */
.highlight .py { color: #A89BB9 } /* Name.Property */

/* Inline code */

tt.code, code.code {
    border: 1px solid #F2F2F2;
    font-weight: normal;
    display: inline;
    padding: 0.3em 0.5em;
    background-color: #FAFAFA;
}
tt.code .name, code.code .name { color: #8A8A8A }
tt.code .operator, code.code .operator { color: #8A8A8A }
tt.code .punctuation, code.code .punctuation { color: #8A8A8A }
tt.code .string, code.code .string { color: #7BBDA4 }
tt.code .number, code.code .number { color: #F4BC87 }
tt.code .integer, code.code .integer { color: #F4BC87 }


/***** Eighties *****/

.highlight .s { color: #59B6CF } /* Literal.String */
.highlight .s1 { color: #59B6CF } /* Literal.String */
.highlight .si { color: #8986BF } /* Literal.String */
.highlight .m { color: #F9768F } /* Literal.Number */
.highlight .mf { color: #F9768F } /* Literal.Number */
.highlight .mh { color: #F9768F } /* Literal.Number */
.highlight .mi { color: #F9768F } /* Literal.Number */
.highlight .mo { color: #F9768F } /* Literal.Number */
.highlight .k { color: #579ED1; font-weight: normal; } /* Keyword */
.highlight .kn { color: #579ED1; font-weight: normal; } /* Keyword */
.highlight .ow { color: #579ED1; font-weight: normal } /* Operator.Word */
.highlight .nc { color: #69B69F; font-weight: 400 } /* Name.Class */
.highlight .nf { color: #8986BF; font-weight: normal; } /* Name.Function */
.highlight .bp { color: #69B69F } /* Name.Builtin.Pseudo */
.highlight .vc { color: #69B69F } /* Name.Variable.Class */
.highlight .vg { color: #69B69F } /* Name.Variable.Global */
.highlight .vi { color: #69B69F } /* Name.Variable.Instance */
.highlight .nd { color: #879ED1 } /* Name.Decorator */
.highlight .ne { color: #CB6077; font-weight: 400 } /* Name.Exception */
.highlight .o { color: #98AEC5 } /* Operator */
.highlight .n { color: #788EA5 }
.highlight .c { color: #A8AFC2; font-style: normal; }
.highlight .sd { color: #A8AFC2; font-style: normal; }
.highlight .nl { color: #F9768F } /* Name.Label */
.highlight .nn { color: #8986BF } /* Name.Namespace */
.highlight .nx { color: #F9768F } /* Name.Other */
.highlight .py { color: #F9768F } /* Name.Property */
.highlight .nb { color: #63ABA3 } /* Name.Builtin */
.highlight .p { color: #98AEC5 } /* Punctuation */

/* Inline code */

tt.code, code.code {
    border: 1px solid #F2F2F2;
    font-weight: normal;
    display: inline;
    padding: 0.3em 0.5em;
    background-color: #FAFAFA;
}
tt.code .name, code.code .name { color: #788EA5 }
tt.code .operator, code.code .operator { color: #98AEC5 }
tt.code .punctuation, code.code .punctuation { color: #98AEC5 }
tt.code .string, code.code .string { color: #59B6CF }
tt.code .number, code.code .number { color: #F9768F }
tt.code .integer, code.code .integer { color: #F9768F }
tt.code .pseudo, code.code .pseudo { color: #69B69F }

/* API */
.rst-content dl:not(.docutils) .property {
    font-family: "Source Code Pro", "Consolas", "Menlo", "Monaco", "Courier New", Courier, monospace;
    padding-right: 5px;
}
.rst-content dl:not(.docutils) em {
    font-family: "Source Code Pro", "Consolas", "Menlo", "Monaco", "Courier New", Courier, monospace;
    font-style: normal;
    color: #788EA5;
}

.rst-content dl.class:not(.docutils) > dt > code {
    font-family: "Source Code Pro", "Consolas", "Menlo", "Monaco", "Courier New", Courier, monospace;
    color: #788EA5;
}

.rst-content dl:not(.docutils) > dt > tt.descname,
.rst-content dl:not(.docutils) > dt > tt.descname,
.rst-content dl:not(.docutils) > dt > code.descname {
    color: #69B69F;
}

.rst-content dl.class:not(.docutils) > dt > .sig-paren,
.rst-content dl:not(.docutils) dl.classmethod > dt > .sig-paren,
.rst-content dl:not(.docutils) dl.method > dt > .sig-paren

{
    font-family: "Source Code Pro", "Consolas", "Menlo", "Monaco", "Courier New", Courier, monospace;
    color: #98AEC5;
    font-weight: normal;
    font-style: normal;
}

.rst-content dl:not(.docutils) dl.classmethod > dt > code,
.rst-content dl:not(.docutils) dl.method > dt > code {
    color: #8986BF;
    font-weight: 400;
}

.rst-content table.field-list .field-body strong {
    color: #F9768F;
    font-weight: 600;
}

.o {
    font-weight: normal;
}

/* Dark Orator */

div[class^="highlight"] {
    border: 0;
    background: #152B39;
    border-radius: 3px;
}

div[class^="highlight"] > pre {
    border: 0;
    color: #98AEC5;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    padding: 4% 4%;
}

.highlight .nn, .highlight .nc { color: #89C6BF; }
.highlight .c, .highlight .c1 { color: #727995; font-style: normal; }
.highlight .sd { color: #727995; font-style: normal; }
.highlight .p, .highlight .o, code.code .operator { color: #687E95 }
.highlight .n, code.code .name { color: #98AEC5 }
.highlight .l { color: #98AEC5; }

.note .last pre,
.warning .last pre,
.tip .last pre,
.caution .last pre,
.versionchanged .last pre,
.versionadded .last pre {
    padding-bottom: 4%;
    margin-bottom: 0;
}
