# -*- coding: utf-8 -*-

from cleo import Command


class HelloCommand(Command):
    """
    Complete me please.

    hello
        { --dangerous-option= : This $hould be `escaped`. }
        { --option-without-description }
    """
